@@ -25,8 +25,6 @@ pub mod simple_voter {
         bump: u8,
         proposal_threshold: u64,
     ) -> ProgramResult {
-        msg!("Instruction: initialize_electorate");
-
         let electorate = &mut ctx.accounts.electorate;
         electorate.bump = bump;
         electorate.proposal_threshold = proposal_threshold;
@@ -39,8 +37,6 @@ pub mod simple_voter {
 
     #[access_control(ctx.accounts.validate())]
     pub fn initialize_token_record(ctx: Context<InitializeTokenRecord>, bump: u8) -> ProgramResult {
-        msg!("Instruction: initialize_token_record");
-
         let token_record = &mut ctx.accounts.token_record;
         token_record.bump = bump;
         token_record.balance = ctx.accounts.gov_token_vault.amount;
@@ -53,15 +49,11 @@ pub mod simple_voter {
 
     #[access_control(ctx.accounts.validate())]
     pub fn activate_proposal(ctx: Context<ActivateProposal>) -> ProgramResult {
-        msg!("Instruction: activate_proposal");
-
         processor::proposer::activate_proposal(ctx)
     }
 
     #[access_control(ctx.accounts.validate())]
     pub fn deposit_tokens(ctx: Context<TokenContext>, amount: u64) -> ProgramResult {
-        msg!("Instruction: deposit_tokens");
-
         ctx.accounts.transfer_to_vault(amount)?;
 
         let token_record = &mut ctx.accounts.token_record;
@@ -74,8 +66,6 @@ pub mod simple_voter {
 
     #[access_control(ctx.accounts.validate())]
     pub fn withdraw_tokens(ctx: Context<TokenContext>, amount: u64) -> ProgramResult {
-        msg!("Instruction: withdraw_tokens");
-
         ctx.accounts.transfer_from_vault(amount)?;
 
         let token_record = &mut ctx.accounts.token_record;
@@ -92,21 +82,16 @@ pub mod simple_voter {
 
     #[access_control(ctx.accounts.validate())]
     pub fn cast_votes(ctx: Context<VoterContext>, vote_side: u8, reason: String) -> ProgramResult {
-        msg!("Instruction: cast_votes");
-        // TODO(michael): Check that proposal is active
         msg!(&reason[..]);
         processor::voter::process_cast_votes(ctx, vote_side)
     }
 
     #[access_control(ctx.accounts.validate())]
     pub fn withdraw_votes(ctx: Context<VoterContext>) -> ProgramResult {
-        msg!("Instruction: withdraw_votes");
-        // TODO(michael): Check that proposal is active
         processor::voter::process_withdraw_votes(ctx)
     }
 
     pub fn finalize_votes(ctx: Context<FinalizeVote>) -> ProgramResult {
-        msg!("Instruction: finalized_votes");
         invariant!(
             ctx.accounts.proposal.get_state(&ctx.accounts.governor)? != ProposalState::Active
         );
